# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-12-14 06:04
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('languages_plus', '0003_auto_20150803_1140'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='language',
            name='iso_639_6',
        ),
        migrations.RemoveField(
            model_name='language',
            name='name_other',
        ),
    ]
